@@ -2,7 +2,7 @@
 # read only color holding object with methods for relation, mixing and transitions
 
 package Graphics::Toolkit::Color;
-our $VERSION = '1.50';
+our $VERSION = '1.51';
 use v5.12;
 
 use Carp;
@@ -487,10 +487,9 @@ The I<distance> is  measured in HSL space unless told otherwise.
 It takes three arguments, only the first is required.
 
 1. Second color (C2) in any scalar definition as I<new> would accept
-(see chapter L<CONSTRUCTOR>).
+(see chapter L</CONSTRUCTOR>).
 
-2. The color space the difference is measured in.
- (see L<Graphics::Toolkit::Color::Value/COLOR-SPACES>)
+2. The color space the difference is measured in. (see L<Graphics::Toolkit::Color::Value/COLOR-SPACES>)
 
 3. The subspace as a string. For instance you want to ignore lightness
 in HSL, then you subspace would be I<'hs'> (initials of the other two dimensions).
@@ -549,11 +548,10 @@ It takes three named arguments, only the first is required.
    L<Graphics::Toolkit::Color::Value/COLOR-SPACES>). Name of the argument
    is I<in>.
 
-
-    my $c = $color->blend_with( Graphics::Toolkit::Color->new('silver') );
-    $color->blend_with( 'silver' );                        # same thing
-    $color->blend_with( [192, 192, 192] );                 # still same
-    my $difference = $color->blend_with( $c2, -1 );
+    # a little more silver than $color in the mix
+    $color->blend( with => 'silver', pos => 0.6 );
+    $color->blend({ with => 'silver', pos => 0.6 });             # works too!
+    $blue->blend( with => {H => 240, S =>100, L => 50}, in => 'RGB' ); # teal
 
 =head1 COLOR SET CREATION METHODS
 
