@@ -98,13 +98,15 @@ __END__
 
 =head1 NAME
 
-The base color space is currently RGB.
 Graphics::Toolkit::Color::Value - convert, format and measure color values
 
 =head1 SYNOPSIS
 
-    use Graphics::Toolkit::Color::Value;
+Central hub for all color value related math. Can handle vectors of all
+spaces mentioned in next paragraph and translates also into and from
+different formats such as I<RGB> I<hex> ('#AABBCC').
 
+    use Graphics::Toolkit::Color::Value;
 
     my @hsl = G.::T.::C.::Value::convert( [20, 50, 70], 'HSL' );    # convert from RGB to HSL
     my @rgb = G.::T.::C.::Value::deconvert( [220, 50, 70], 'HSL' ); # convert from HSL to RGB
@@ -112,15 +114,13 @@ Graphics::Toolkit::Color::Value - convert, format and measure color values
 
 =head1 DESCRIPTION
 
-Central hub for all color value related math. Can handle vectors of all
-spaces mentioned in next paragraph and translates also into and from
-different formats such as I<RGB> I<hex> ('#AABBCC'). This module is
-supposed to be used by L<Graphics::Toolkit::Color> and not directly.
+This module is supposed to be used by L<Graphics::Toolkit::Color> and not
+directly, thus it exports no symbols and has a much less DWIM API then
+the main module.
 
 
 =head1 COLOR SPACES
 
-
 Color space names can be written in any combination of upper and lower case.
 
 =head2 RGB
